pub trait ScalarData: Sealed { }Expand description
Marker trait for scalar buffers.
This trait can not be implemented outside the crate.
pub trait ScalarData: Sealed { }Marker trait for scalar buffers.
This trait can not be implemented outside the crate.